#
# spec file for package 0ad
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Enable NVTT only on arch supported by nvidia-texture-tools
%ifarch %{ix86} x86_64 ppc
%bcond_without nvtt
%else
%bcond_with nvtt
%endif
# We can use the system mozjs on Tumbleweed and Leap 15.4.
%if 0%{?suse_version} > 1500 || 0%{?sle_version} >= 150400
%bcond_without system_mozjs
%else
%bcond_with system_mozjs
%endif
# Use provided library
%bcond_without system_nvtt
Name:           0ad
Version:        0.0.26
Release:        7.2
Summary:        A real-time strategy game of ancient warfare
License:        BSD-3-Clause AND CC-BY-SA-3.0 AND GPL-2.0-or-later AND LGPL-3.0-or-later AND MIT AND ISC AND MPL-2.0
Group:          Amusements/Games/Strategy/Real Time
URL:            https://play0ad.com/
Source:         https://releases.wildfiregames.com/%{name}-%{version}-alpha-unix-build.tar.xz
# PATCH-FIX-UPSTREAM
Patch0:         avoid_duplicate_global_symbol_from_asm.patch
# PATCH-FIX-OPENSUSE -- Disable the mozjs version check
Patch1:         no-version-check.patch
# PATCH-FIX-OPENSUSE -- Use the newer variant of this function (related to mozjs78 upgrade)
Patch2:         PrepareZoneForGC.patch
# PATCH-FIX-OPENSUSE -- Skip automatic addition of an RPATH.
Patch3:         premake-no-automatic-rpath.patch
# PATCH-FIX-UPSTREAM -- Fix build with GCC 13
Patch4:         fix-gcc13-build.patch
# PATCH-FIX-UPSTREAM -- Fix build with fmt 10
Patch5:         fix-fmt10-build.patch
# PATCH-FIX-UPSTREAM -- Fix build with boost 1.85
Patch6:         fix-boost-1.85-build.patch
# PATCH-FIX-UPSTREAM -- Fix build with icu 76.x
Patch7:         0ad-link-icu-76.patch
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  libXcursor-devel
BuildRequires:  libboost_filesystem-devel
BuildRequires:  libboost_system-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libminiupnpc-devel
BuildRequires:  libpng-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  wxWidgets-devel
BuildRequires:  pkgconfig(IL)
BuildRequires:  pkgconfig(fmt)
BuildRequires:  pkgconfig(gloox)
BuildRequires:  pkgconfig(gnutls)
BuildRequires:  pkgconfig(icu-i18n)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libenet)
BuildRequires:  pkgconfig(libidn)
BuildRequires:  pkgconfig(libsodium) >= 1.0.13
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(openal)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(vorbis)
BuildRequires:  pkgconfig(zlib)
Requires:       0ad-data = %{version}
%if %{with nvtt} && %{with system_nvtt}
BuildRequires:  nvidia-texture-tools >= 2.1
%endif
%if %{with system_mozjs}
#FIXME: Depends on source/scriptinterface/ScriptTypes.h
# This is "fixed" by disabling the version check.
BuildRequires:  pkgconfig(mozjs-78) >= 78.7
%else
BuildRequires:  cargo
BuildRequires:  rust
%endif
ExcludeArch:    s390x

%description
0 A.D. (pronounced "zero ey-dee") is a real-time strategy (RTS) game
of ancient warfare. It is a historically-based war/economy game that
allows players to relive or rewrite the history of Western
civilizations, focusing on the years between 500 B.C. and 500 A.D.
The project contains 3D graphics, detailed artwork, sound, and a
flexible game engine.

%prep
%setup -q -n %{name}-%{version}-alpha
%patch -P 0 -p1
%patch -P 3 -p1
%patch -P 4 -p1
%patch -P 5 -p1
%if %{with system_mozjs}
%patch -P 1 -p1
%patch -P 2 -p1
%endif
%if %{pkg_vcmp libboost_filesystem-devel >= 1.74}
%patch -P 6 -p1
%endif
%patch -P 7 -p1

%build
export CFLAGS="%{optflags}"
# bundled Collada uses CCFLAGS
export CCFLAGS="%{optflags}"
export CPPFLAGS="%{optflags} -fpermissive"
# Copied from macros.cmake.
export LDFLAGS="-Wl,--as-needed -Wl,--no-undefined -Wl,-z,now"
build/workspaces/update-workspaces.sh \
    %{?_smp_mflags} \
    --bindir=%{_bindir} \
    --datadir=%{_datadir}/%{name} \
    --libdir=%{_libdir}/%{name} \
    --without-tests \
%if %{with nvtt}
%if %{with system_nvtt}
    --with-system-nvtt \
%endif
%else
    --without-nvtt \
%endif
%if %{with system_mozjs}
    --with-system-mozjs
%else
export CARGO_PROFILE_RELEASE_LTO=true
%endif

pushd build/workspaces/gcc
%make_build verbose=1
popd

%install
mkdir -p %{buildroot}%{_libdir}/%{name}
mkdir -p %{buildroot}%{_datadir}/%{name}
# Install binaries and wrapper
install -Dm 0755 binaries/system/ActorEditor %{buildroot}%{_bindir}/ActorEditor
install -Dm 0755 binaries/system/pyrogenesis %{buildroot}%{_bindir}/pyrogenesis
install -Dm 0755 build/resources/0ad.sh %{buildroot}%{_bindir}/0ad
# Install game libraries
install -m 0644 binaries/system/libCollada.so %{buildroot}%{_libdir}/%{name}/libCollada.so
install -m 0644 binaries/system/libAtlasUI.so %{buildroot}%{_libdir}/%{name}/libAtlasUI.so
# If without system mozjs we need to install the bundled one
%if %{without system_mozjs}
install -m 0644 binaries/system/libmozjs*-ps-release.so %{buildroot}%{_libdir}/%{name}/
%endif
# Install appdata
install -Dm 0644 build/resources/0ad.desktop %{buildroot}%{_datadir}/applications/%{name}.desktop
install -Dm 0644 build/resources/0ad.appdata.xml %{buildroot}%{_datadir}/appdata/%{name}.appdata.xml
install -Dm 0644 build/resources/0ad.png %{buildroot}%{_datadir}/pixmaps/%{name}.png

%suse_update_desktop_file %{name}

%files
%doc README.txt
%license LICENSE.txt license_gpl-2.0.txt license_lgpl-2.1.txt license_mit.txt
%{_bindir}/0ad
%{_bindir}/pyrogenesis
%{_bindir}/ActorEditor
%{_libdir}/%{name}/
%{_datadir}/pixmaps/%{name}.png
%{_datadir}/appdata/%{name}.appdata.xml
%{_datadir}/applications/%{name}.desktop
%dir %{_datadir}/%{name}

%changelog
* Fri Dec 20 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Replace wxWidgets-3_0-nostl-devel with wxWidgets-devel
  BuildRequires.
* Fri Nov 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Add 0ad-link-icu-76.patch: Fix build against ICU 76.x.
* Thu Apr 25 2024 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Add fix-boost-1.85-build.patch to fix build with boost 1.85.
* Fri Mar  8 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Tue Dec  5 2023 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Add fix-fmt10-build.patch to fix build with libfmt 10.
* Sat Mar 25 2023 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Add fix-gcc13-build.patch to fix build with GCC 13.
* Mon Sep 26 2022 C J <c.j@tuta.io>
- Update to 0.0.26
- Remove obsolete glibc-2.35.patch.
* Wed Aug 10 2022 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Fix rpmlint by adding premake-no-automatic-rpath.patch: don't let
  premake automatically add RPATHs, these are unnecessary.
- Add distribution default link flags, especially -Wl,-z,now.
* Sun Jun 26 2022 Berthold Gunreben <azouhr@opensuse.org>
- s390x CPU not implemented.
  ExcludeArch: s390x
* Wed Mar 23 2022 Bernhard Wiedemann <bwiedemann@suse.com>
- Drop fix-i586-build.patch after boo#1197065 was fixed
* Sun Mar 13 2022 Bernhard Wiedemann <bwiedemann@suse.com>
- Add fix-i586-build.patch to fix build on i586
* Fri Mar 11 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Do not build on i586.
* Sun Feb 20 2022 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Add glibc-2.35.patch: Fix build with glibc 2.35.
- Use system mozjs on Leap 15.4 as well.
* Tue Jan 11 2022 Simon Puchert <simonpuchert@alice.de>
- Get rid of Python 2 dependency.
- Disable tests. These require Python 2 to work, but also aren't
  executed or packaged anyway.
- Remove duplicate listing of %%{_libdir}/%%{name}.
* Fri Jan  7 2022 Simon Puchert <simonpuchert@alice.de>
- Make 0ad compatible with Tumbleweed's version of mozjs78:
  * no-version-check.patch: Disable the minor version check. This
    is required for a successful build using mozjs78 > 78.6.0.
  * PrepareZoneForGC.patch: This function got an additional
    parameter, change its usage accordingly. (boo#1187732)
* Sun Aug 29 2021 ecsos <ecsos@opensuse.org>
- Update to version 0.0.25b:
  * Ranked matches did not longer grant points in the lobby.
  * Mod installation no longer require restart.
  * Mod installation no longer prints errors when installing mods by double-clicking
  * Mod installation now overwrites the existing mods to allow for easier updates.
  * Fishes are now easier to spot on lowest settings with the addition of seagulls.
  * See https://wildfiregames.com/forum/topic/53714-re-release-of-0-ad-alpha-25-yauna/
- Increase disk size in _constraints to fix build error
  "No space left on device" in Leap.
* Mon Aug 16 2021 Simon Puchert <simonpuchert@alice.de>
- Update to version 0.0.25:
  * See https://play0ad.com/new-release-0-a-d-alpha-25-yauna/
- Dropped mozjs-rust_1_50.patch, merged upstream
* Tue Apr 27 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- BuildRequires nvidia-texture-tools only when needed
* Mon Apr 26 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Enable nvidia-texture-tools only on supported archs
* Fri Apr  9 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Install bundled mozjs if needed (boo#1184063)
* Tue Mar  9 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 0.0.24b:
  * See https://play0ad.com/new-release-0-a-d-alpha-24-xsayarsa/
  * Added upstream mozjs-rust_1_50.patch for Factory
- Dropped upstream merged patches:
  * 0001-fix-fcollada-error.patch
  * 0001-Fix-ODR-violation-for-ShaderModelRendererInternals.patch
* Mon Aug  3 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix build on ix86 in combination with LTO, the bundled mbedtls
  from premake5 creates duplicate symbols from inline asm.
  Add avoid_duplicate_global_symbol_from_asm.patch
- Add 0001-Fix-ODR-violation-for-ShaderModelRendererInternals.patch
- Clean up dozens of unnecessary build dependencies.
* Sun Aug  2 2020 Simon Vogl <simon.vogl@gmx.net>
- Disable --with-system-mozjs38 option on systems which lack the mozjs38 package
- Include the libmozjs38-ps-release.so binary on systems which lack the mozjs38 package
- Require more build dependencies on systems which lack the mozjs38 package
- Add 0001-fix-fcollada-error.patch to fix a build failure with gcc10
* Fri Dec 20 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Disable LTO on i586.
* Mon May 20 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add _constraints to avoid build failures due to OOM
* Tue Apr  9 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Spec file cleanup:
  * Use https for Url and Source tags
  * Remove defattr
  * Remove __DATE__ mangling, handled by GCC + SOURCE_DATE_EPOCH
  * Remove support for Leap 42.x, unresolvable anyway
* Tue Dec 25 2018 Michael Vetter <mvetter@suse.com>
- Update to 0.0.23b:
  See https://play0ad.com/re-release-of-0-a-d-alpha-23-ken-wood/
* Fri May 18 2018 mvetter@suse.com
- Update to 0.0.23:
  See https://play0ad.com/new-release-0-a-d-alpha-23-ken-wood/
- Remove fix_abs_of_unsigned_char_on_arm.patch: upstreamed
- Remove system-tinygettext.patch:
  Upstream thinks this might lead to problems
  See https://trac.wildfiregames.com/ticket/4192
- Add BuildReq libsodium and remove tinygettext to use shipped one
* Fri Mar  9 2018 stefan.bruens@rwth-aachen.de
- Keep fix_abs_of_unsigned_char_on_arm.patch intact and disable
  the conflicting/irrelevant hunk in the spec file
* Sun Feb 25 2018 stefan.bruens@rwth-aachen.de
- Revert the changes to use bundled mozjs38 on Leap 42.3 again
  (no changelog entry), it does not build on 42.3. Use fixed
  mozjs38 from distribution instead.
* Sat Feb 24 2018 stefan.bruens@rwth-aachen.de
- Add fix_abs_of_unsigned_char_on_arm.patch, fixes build on 32/64
  bit ARM (and probably PPC)
* Sat Feb  3 2018 guillaume@opensuse.org
- Enable nvidia-texture-tools only on supported archs
* Fri Feb  2 2018 stefan.bruens@rwth-aachen.de
- Use system mozjs38, bundled one fails to build on TW
- Remove special handling for Leap 42.1
- Pass compiler flags to bundled Collada
* Tue Nov 21 2017 adam.majer@suse.de
- Stop depending on boost-devel (boo#1062766)
* Fri Aug 11 2017 mailaender@opensuse.org
- Build with system nvidia-texture-tools (boo#1053393)
* Fri Jul 28 2017 dimstar@opensuse.org
- Update to version 0.0.22:
  + Remake of many models, animations and textures, two new music
    tracks.
  + Configuration-free Multiplayer Hosting.
  + Capture the Relic Gamemode.
  + Aura and Heal Range Visualization.
  + Twelve new maps, including scripted enemies, rising water and a
    tutorial.
  + Espionage Technology, Team Bonuses and Hero Auras.
  + Petra AI Diplomacy and Attack Strategies.
  + Summary Screen Graphs.
  + Cinema Path Editing.
  + Buddy System.
- Drop 0ad-desktop.patch: fixed upstream.
* Fri Feb 17 2017 dimstar@opensuse.org
- Install the upstream provided appdata.xml file.
* Wed Dec  7 2016 ecsos@opensuse.org
- Update to version 0.0.21
  See: https://play0ad.com/new-release-0-a-d-alpha-21-ulysses/
- Add patch 0ad-desktop.patch because of rpmlint-error invalid-
  desktopfile invalid key URL
- Drop patch fix-c++14-compat.patch because now in upstream
- Rebase patch system-tinygettext.patch
* Tue Aug 30 2016 rpm@fthiessen.de
- Added system-tinygettext.patch
- Removed code for other distributions from spec file, sine we just
  build for openSUSE.
* Fri Jul 29 2016 jengelh@inai.de
- Update License field and trim filler words from description.
* Mon Jun 27 2016 rpm@fthiessen.de
- Fixed build with gcc6 (Tumbleweed), added fix-c++14-compat.patch
* Mon May 16 2016 jengelh@inai.de
- Build with wxWidgets 3 and reenable dependency generation
* Mon Apr  4 2016 mvetter@suse.com
- Update to version 0.0.20
  * New maps
  * Better graphics and Camera
  See https://play0ad.com/new-release-0-a-d-alpha-20-timosthenes/
* Sat Apr  2 2016 bwiedemann@suse.com
- use changelog time instead of build time to fix build-compare
* Thu Nov 26 2015 mvetter@suse.com
- Update to version 0.0.19
* Tue Apr  7 2015 g.bluehut@gmail.com
- Use xz archive instead of gz
* Thu Apr  2 2015 opensuse@oeschti.de
- update to version 0.0.18
- use libminiupnpc-devel instead of builtin libminiupnpc
* Mon Oct 13 2014 opensuse@dstoecker.de
- update to version 0.0.17
* Sun Oct 12 2014 bwiedemann@suse.com
- use builtin libminiupnpc to work inspite of incompatible OS version
* Mon May 26 2014 adrian@suse.de
- require same versioned data package
* Wed May 21 2014 adrian@suse.de
- build using external libicu
* Tue May 20 2014 adrian@suse.de
- Update to version 0.0.16.
* Sat Jan  4 2014 aj@ajaissle.de
- Update to version 0.0.15.
* Tue Sep 10 2013 mailaender@opensuse.org
- Update to version 0.0.14.
- Adhere to https://en.opensuse.org/SourceUrls
* Wed Apr  3 2013 dimstar@opensuse.org
- Update to version 0.0.13.
* Sun Jan 13 2013 joop.boonen@opensuse.org
- Added BuildRequires libXcursor-devel as they are not
  automatically installed for openSUSE > 12.2
* Sun Dec 16 2012 philip@zaynar.co.uk
- Update to 0.0.12
- Remove obsolete unused Debian build scripts
* Sun Oct 14 2012 philip@zaynar.co.uk
- Update to 0.0.11
- New version number scheme
- Remove fam/gamin dependency
* Wed May 16 2012 philip@zaynar.co.uk
- Update to r11863
* Thu Mar 15 2012 philip@zaynar.co.uk
- Update to r11339
* Fri Dec 23 2011 philip@zaynar.co.uk
- Update to r10803
* Sat Sep 17 2011 philip@zaynar.co.uk
- Update to r10288
* Sun Jul 10 2011 philip@zaynar.co.uk
- Update to r9786
- libenet0-devel -> libenet-devel
* Fri May 20 2011 philip@zaynar.co.uk
- Update to r9530
- libenet-devel -> libenet0-devel
* Fri Mar 11 2011 philip@zaynar.co.uk
- Update to r9049
* Mon Feb 21 2011 reddwarf@opensuse.org
- wxGTK -> wxWidgets migration
* Fri Dec 10 2010 philip@zaynar.co.uk
- Update to r8832
* Sun Oct 17 2010 philip@zaynar.co.uk
- Update to r8413
* Sun Aug 15 2010 philip@zaynar.co.uk
- Update to r7970
- Compile in Release mode
* Mon Jul 12 2010 bitshuffler@opensuse.org
- Initial package
